@@ -1,15 +1,10 @@
 use strict;
 package Plack::Middleware::Image::Scale;
-BEGIN {
-  $Plack::Middleware::Image::Scale::AUTHORITY = 'cpan:PNU';
-}
-{
-  $Plack::Middleware::Image::Scale::VERSION = '0.009';
-}
+our $AUTHORITY = 'cpan:PNU';
 # ABSTRACT: Resize jpeg and png images on the fly
 
 use Moose;
-use Class::MOP;
+use Class::Load;
 use Plack::Util;
 use Plack::MIME;
 use Try::Tiny;
@@ -19,6 +14,8 @@ use Carp;
 
 extends 'Plack::Middleware';
 
+our $VERSION = '0.011'; # VERSION
+
 
 has path => (
     is => 'rw', lazy => 1, isa => 'RegexpRef|CodeRef|Str|Undef',
@@ -46,7 +43,7 @@ has any_ext => (
 
 has orig_ext => (
     is => 'rw', lazy => 1, isa => 'ArrayRef',
-    default => sub { [qw( jpg png gif )] }
+    default => sub { [qw( jpg png gif jpeg )] }
 );
 
 
@@ -113,7 +110,7 @@ sub call {
             $ct = Plack::MIME->mime_type(".$ext");
             Plack::Util::header_set( $res->[1], 'Content-Type', $ct );
         }
-        return $self->body_scaler( $ct, @param, $orig_ct );
+        return $self->body_scaler( $ct, $orig_ct, @param );
     });
 }
 
@@ -191,7 +188,7 @@ sub body_scaler {
 
 
 sub image_scale {
-    my ($self, $bufref, $ct, $width, $height, $flags, $orig_ct) = @_;
+    my ($self, $bufref, $ct, $orig_ct, $width, $height, $flags) = @_;
 
     ## $flags can be a HashRef, or it's parsed as a string
     my %flag = 'HASH' eq ref $flags ? %{ $flags } :
@@ -210,10 +207,10 @@ sub image_scale {
     }
 
     my $output;
-    if ($orig_ct eq 'application/pdf') {
+    if (defined $orig_ct and $orig_ct eq 'application/pdf') {
         try {
-            Class::MOP::load_class('Image::Magick::Thumbnail::PDF');
-            Class::MOP::load_class('File::Temp');
+            Class::Load::load_class('Image::Magick::Thumbnail::PDF');
+            Class::Load::load_class('File::Temp');
             my $in = File::Temp->new( SUFFIX => '.pdf' );
             my $out = File::Temp->new( SUFFIX => '.png' );
             $in->write( $$bufref ); $in->close;
@@ -271,7 +268,7 @@ sub image_scale {
     if ( defined $owidth  and $width  > $owidth or
          defined $oheight and $height > $oheight ) {
         try {
-            Class::MOP::load_class('Imager');
+            Class::Load::load_class('Imager');
             my $img = Imager->new;
             $img->read( data => $output ) || die;
             my $crop = $img->crop(
@@ -293,18 +290,23 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Plack::Middleware::Image::Scale - Resize jpeg and png images on the fly
 
 =head1 VERSION
 
-version 0.009
+version 0.011
 
 =head1 SYNOPSIS
 
     ## example1.psgi
-    
+    use Plack::Builder;
+    use Plack::Middleware::Image::Scale;
+    my $app = sub { return [200,[],[]] };
+
     builder {
         enable 'ConditionalGET';
         enable 'Image::Scale';
@@ -312,10 +314,14 @@ version 0.009
         $app;
     };
 
-A request to /images/foo_40x40.png will use images/foo.(png|jpg|gif) as
+A request to /images/foo_40x40.png will use images/foo.(png|jpg|gif|jpeg) as
 original, scale it to 40x40 px size and convert to PNG format.
 
     ## example2.psgi
+    use Plack::Builder;
+    use Plack::App::File;
+    use Plack::Middleware::Image::Scale;
+    my $app = sub { return [200,['Content-Type'=>'text/plain'],['hello']] };
 
     my $thumber = builder {
         enable 'ConditionalGET';
@@ -330,46 +336,12 @@ original, scale it to 40x40 px size and convert to PNG format.
         mount '/' => $app;
     };
 
-A request to /thumbs/foo.png will use images/foo.(png|jpg|gif) as original,
+A request to /thumbs/foo.png will use images/foo.(png|jpg|gif|jpeg) as original,
 scale it small enough to fit 200x100 px size, fill extra borders (top/down or
 left/right, depending on the original image aspect ratio) with cyan
 background, and convert to PNG format. Also clipping is available, see
 L</CONFIGURATION>.
 
-    ## see example4.psgi
-
-    my %imagesize = Config::General->new('imagesize.conf')->getall;
-    
-    # ...
-    
-    enable 'Image::Scale', size => \%imagesize;
-
-A request to /images/foo_medium.png will use images/foo.(png|jpg|gif) as
-original. The size and flags are taken from the configuration file as
-parsed by Config::General.
-
-    ## imagesize.conf
-
-    <medium>
-        width   200
-        height  100
-        crop
-    </medium>
-    <big>
-        width   300
-        height  100
-        crop
-    </big>
-    <thumbred>
-        width   50
-        height  100
-        fill    ff0000
-    </thumbred>
-
-For more examples, browse into directory
-L<eg|http://cpansearch.perl.org/src/PNU/> inside the distribution
-directory for this version.
-
 =head1 DESCRIPTION
 
 Scale and convert images to the requested format on the fly. By default the
@@ -571,6 +543,42 @@ not change the crop size.
 
     /images/foo_40x-z20.png
 
+=head1 EXAMPLES
+
+    ## see example4.psgi
+
+    my %imagesize = Config::General->new('imagesize.conf')->getall;
+
+    # ...
+
+    enable 'Image::Scale', size => \%imagesize;
+
+A request to /images/foo_medium.png will use images/foo.(png|jpg|gif|jpeg) as
+original. The size and flags are taken from the configuration file as
+parsed by Config::General.
+
+    ## imagesize.conf
+
+    <medium>
+        width   200
+        height  100
+        crop
+    </medium>
+    <big>
+        width   300
+        height  100
+        crop
+    </big>
+    <thumbred>
+        width   50
+        height  100
+        fill    ff0000
+    </thumbred>
+
+For more examples, browse into directory
+L<eg|http://cpansearch.perl.org/src/PNU/> inside the distribution
+directory for this version.
+
 =head1 CAVEATS
 
 The cropping requires L<Imager>. This is a run-time dependency, and
@@ -590,7 +598,7 @@ Panu Ervamaa <pnu@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Panu Ervamaa.
+This software is copyright (c) 2011-2016 by Panu Ervamaa.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
