@@ -9,9 +9,9 @@ has method => ( is => 'ro', isa => 'Str' );
 has method_orig => ( is => 'rw' );
 
 has _log => (
-    isa     => 'ArrayRef[ArrayRef]', 
+    isa     => 'ArrayRef[ArrayRef]',
     default => sub { [] },
-    traits  => ['Array'], 
+    traits  => ['Array'],
     handles => {
         push   => 'push',
         pop    => 'pop',
@@ -33,7 +33,8 @@ sub BUILD {
 sub DEMOLISH {
     my $self = shift;
     my $meta = Class::MOP::Class->initialize( $self->class );
-    $meta->add_method( $self->method, $self->method_orig );
+    $meta->add_method( $self->method, $self->method_orig )
+        if defined $self->method_orig;
 }
 
 1;
